@@ -27,10 +27,12 @@ def SchedulerMethod(*methodArgs, requestClass=None, **methodKwargs) :
     methodKwargs['id'] = shedulerId
     methodKwargs['max_instances'] = instancesUpTo
     methodKwargs['day_of_week'] = weekDays
+    shedulerArgs = [*methodArgs]
+    shedulerKwargs = {**methodKwargs}
     def innerMethodWrapper(resourceInstanceMethod, *innerMethodArgs, **innerMethodKwargs) :
         log.debug(SchedulerMethod,f'''wrapping {resourceInstanceMethod.__name__}''')
         apiInstance = resourceInstanceMethod.__self__.globals.api
-        @apiInstance.scheduler.task(*methodArgs, **methodKwargs)
+        @apiInstance.scheduler.task(*shedulerArgs, **shedulerKwargs)
         def innerResourceInstanceMethod(*args, **kwargs) :
             args = FlaskManager.getArgumentInFrontOfArgs(args, ReflectionHelper.getAttributeOrMethod(apiInstance.resource.scheduler, methodClassName[:-len('Scheduler')].lower()))
             resourceInstance = args[0]
